@@ -92,7 +92,8 @@ Puppet::Face.define(:epp, '0.0.1') do
         end
       end
       if !missing_files.empty?
-        raise Puppet::Error, _("One or more file(s) specified did not exist:\n") + missing_files.map { |f| "   #{f}" }.join("\n")
+        raise Puppet::Error, _("One or more file(s) specified did not exist:\n%{missing_files_list}") %
+            { missing_files_list: missing_files.map { |f| "   #{f}" }.join("\n") }
       else
         # Exit with 1 if there were errors
         raise Puppet::Error, _("Errors while validating epp") unless status
@@ -180,7 +181,8 @@ Puppet::Face.define(:epp, '0.0.1') do
         end
 
         if !missing_files.empty?
-          raise Puppet::Error, _("One or more file(s) specified did not exist:\n") + missing_files.collect { |f| "   #{f}" }.join("\n")
+          raise Puppet::Error, _("One or more file(s) specified did not exist:\n%{missing_files_list}") %
+              { missing_files_list:  missing_files.collect { |f| "   #{f}" }.join("\n") }
         end
       end
       buffer.string
