@@ -23,6 +23,7 @@ class Puppet::Module
     "templates" => "templates",
     "plugins" => "lib",
     "pluginfacts" => "facts.d",
+    "locales" => "locales",
   }
 
   # Find and return the +module+ that +path+ belongs to. If +path+ is
@@ -96,9 +97,6 @@ class Puppet::Module
     load_metadata
 
     @absolute_path_to_manifests = Puppet::FileSystem::PathPattern.absolute(manifests)
-
-    # i18n initialization for modules
-    initialize_i18n unless Puppet[:disable_i18n]
   end
 
   # @deprecated The puppetversion module metadata field is no longer used.
@@ -208,7 +206,8 @@ class Puppet::Module
   rescue Errno::ENOENT
     {}
   rescue JSON::JSONError => e
-    msg = "#{name} has an invalid and unparsable metadata.json file. The parse error: #{e.message}"
+    #TRANSLATORS 'metadata.json' is a specific file name and should not be translated.
+    msg = _("%{name} has an invalid and unparsable metadata.json file. The parse error: %{error}") % { name: name, error: e.message }
     case Puppet[:strict]
     when :off
       Puppet.debug(msg)
@@ -302,6 +301,21 @@ class Puppet::Module
     subpath("facts.d")
   end
 
+  #@return [String]
+  def locale_directory
+    subpath("locales")
+  end
+
+  # Returns true if the module has translation files for the
+  # given locale.
+  # @param [String] locale the two-letter language code to check
+  #        for translations
+  # @return true if the module has a directory for the locale, false
+  #         false otherwise
+  def has_translations?(locale)
+    return Puppet::FileSystem.exist?(File.join(locale_directory, locale))
+  end
+
   def has_external_facts?
     File.directory?(plugin_fact_directory)
   end
@@ -422,23 +436,6 @@ class Puppet::Module
     @strict_semver
   end
 
-  def initialize_i18n
-    # this name takes the form "namespace-module", and should match the name of
-    # the PO file containing the translations.
-    module_name = @forge_name ? @forge_name.gsub("/", "-") : name
-    return if Puppet::GettextConfig.translations_loaded?(module_name)
-
-    locales_path = File.absolute_path('locales', path)
-
-    if Puppet::GettextConfig.load_translations(module_name, locales_path, :po)
-      Puppet.debug "i18n initialized for #{module_name}"
-    elsif Puppet::GettextConfig.gettext_loaded?
-      Puppet.debug "Could not find translation files for #{module_name} at #{locales_path}. Skipping i18n initialization."
-    else
-      Puppet.debug "No gettext library found, skipping i18n initialization."
-    end
-  end
-
   private
 
   def wanted_manifests_from(pattern)
