@@ -18,7 +18,7 @@ module Puppet::ModuleTool
         create_directory
         copy_contents
         write_json
-        Puppet.notice "Building #{@path} for release"
+        Puppet.notice _("Building %{path} for release") % { path: @path }
         pack
         relative = Pathname.new(archive_file).relative_path_from(Pathname.new(File.expand_path(Dir.pwd)))
 
@@ -114,10 +114,10 @@ module Puppet::ModuleTool
           symlinks.each do |s|
             s = Pathname.new s
             mpath = Pathname.new @path
-            Puppet.warning "Symlinks in modules are unsupported. Please investigate symlink #{s.relative_path_from mpath} -> #{s.realpath.relative_path_from mpath}."
+            Puppet.warning _("Symlinks in modules are unsupported. Please investigate symlink %{from} -> %{to}.") % { from: s.relative_path_from(mpath), to: s.realpath.relative_path_from(mpath) }
           end
 
-          raise Puppet::ModuleTool::Errors::ModuleToolError, "Found symlinks. Symlinks in modules are not allowed, please remove them."
+          raise Puppet::ModuleTool::Errors::ModuleToolError, _("Found symlinks. Symlinks in modules are not allowed, please remove them.")
         end
       end
 
@@ -125,18 +125,18 @@ module Puppet::ModuleTool
         metadata_path = File.join(build_path, 'metadata.json')
 
         if metadata.to_hash.include? 'checksums'
-          Puppet.warning "A 'checksums' field was found in metadata.json. This field will be ignored and can safely be removed."
+          Puppet.warning _("A 'checksums' field was found in metadata.json. This field will be ignored and can safely be removed.")
         end
 
         # TODO: This may necessarily change the order in which the metadata.json
         # file is packaged from what was written by the user.  This is a
         # regretable, but required for now.
-        File.open(metadata_path, 'w') do |f|
+        Puppet::FileSystem.open(metadata_path, nil, 'w:UTF-8') do |f|
           f.write(metadata.to_json)
         end
 
-        File.open(File.join(build_path, 'checksums.json'), 'w') do |f|
-          f.write(PSON.pretty_generate(Checksums.new(build_path)))
+        Puppet::FileSystem.open(File.join(build_path, 'checksums.json'), nil, 'wb') do |f|
+          f.write(JSON.pretty_generate(Checksums.new(build_path)))
         end
       end
 
