@@ -4,6 +4,7 @@ require 'puppet/ssl/configuration'
 require 'puppet/ssl/validator'
 require 'puppet/network/http'
 require 'uri'
+require 'date'
 
 module Puppet::Network::HTTP
 
@@ -75,7 +76,7 @@ module Puppet::Network::HTTP
     # @!macro common_options
     # @api public
     def get(path, headers = {}, options = {})
-      request_with_redirects(Net::HTTP::Get.new(path, headers), options)
+      do_request(Net::HTTP::Get.new(path, headers), options)
     end
 
     # @param path [String]
@@ -86,7 +87,7 @@ module Puppet::Network::HTTP
     def post(path, data, headers = nil, options = {})
       request = Net::HTTP::Post.new(path, headers)
       request.body = data
-      request_with_redirects(request, options)
+      do_request(request, options)
     end
 
     # @param path [String]
@@ -94,7 +95,7 @@ module Puppet::Network::HTTP
     # @!macro common_options
     # @api public
     def head(path, headers = {}, options = {})
-      request_with_redirects(Net::HTTP::Head.new(path, headers), options)
+      do_request(Net::HTTP::Head.new(path, headers), options)
     end
 
     # @param path [String]
@@ -102,7 +103,7 @@ module Puppet::Network::HTTP
     # @!macro common_options
     # @api public
     def delete(path, headers = {'Depth' => 'Infinity'}, options = {})
-      request_with_redirects(Net::HTTP::Delete.new(path, headers), options)
+      do_request(Net::HTTP::Delete.new(path, headers), options)
     end
 
     # @param path [String]
@@ -113,7 +114,7 @@ module Puppet::Network::HTTP
     def put(path, data, headers = nil, options = {})
       request = Net::HTTP::Put.new(path, headers)
       request.body = data
-      request_with_redirects(request, options)
+      do_request(request, options)
     end
 
     def request(method, *args)
@@ -164,7 +165,7 @@ module Puppet::Network::HTTP
 
     private
 
-    def request_with_redirects(request, options)
+    def do_request(request, options)
       current_request = request
       current_site = @site
       response = nil
@@ -177,9 +178,9 @@ module Puppet::Network::HTTP
 
           current_response = execute_request(connection, current_request)
 
-          if [301, 302, 307].include?(current_response.code.to_i)
-
-            # handle the redirection
+          case current_response.code.to_i
+          when 301, 302, 307
+            # handle redirection
             location = URI.parse(current_response['location'])
             current_site = current_site.move_to(location)
 
@@ -189,6 +190,8 @@ module Puppet::Network::HTTP
             request.each do |header, value|
               current_request[header] = value
             end
+          when 429, 503
+            response = handle_retry_after(current_response)
           else
             response = current_response
           end
@@ -200,6 +203,91 @@ module Puppet::Network::HTTP
       raise RedirectionLimitExceededException, _("Too many HTTP redirections for %{host}:%{port}") % { host: @host, port: @port }
     end
 
+    # Handles the Retry-After header of a HTTPResponse
+    #
+    # This method checks the response for a Retry-After header and handles
+    # it by sleeping for the indicated number of seconds. The response is
+    # returned unmodified if no Retry-After header is present.
+    #
+    # @param response [Net::HTTPResponse] A response recieved from the
+    #   HTTP client.
+    #
+    # @return [nil] Sleeps and returns nil if the response contained a
+    #   Retry-After header that indicated the request should be retried.
+    # @return [Net::HTTPResponse] Returns the `response` unmodified if
+    #   no Retry-After header was present or the Retry-After header could
+    #   not be parsed as an integer or RFC 2822 date.
+    def handle_retry_after(response)
+      retry_after = response['Retry-After']
+      return response if retry_after.nil?
+
+      retry_sleep = parse_retry_after_header(retry_after)
+      # Recover remote hostname if Net::HTTPResponse was generated by a
+      # method that fills in the uri attribute.
+      #
+      # TODO: Drop the respond_to? check when support for Ruby 1.9.3 is dropped.
+      server_hostname = if response.respond_to?(:uri) && response.uri.is_a?(URI)
+                          response.uri.host
+                        else
+                          # TRANSLATORS: Used in the phrase:
+                          # "Received a response from the remote server."
+                          _('the remote server')
+                        end
+
+      if retry_sleep.nil?
+        Puppet.err(_('Received a %{status_code} response from %{server_hostname}, but the Retry-After header value of "%{retry_after}" could not be converted to an integer or RFC 2822 date.') %
+                   {status_code: response.code,
+                    server_hostname: server_hostname,
+                    retry_after: retry_after.inspect})
+
+        return response
+      end
+
+      # Cap maximum sleep at the run interval of the Puppet agent.
+      retry_sleep = [retry_sleep, Puppet[:runinterval]].min
+
+      Puppet.warning(_('Received a %{status_code} response from %{server_hostname}. Sleeping for %{retry_sleep} seconds before retrying the request.') %
+                     {status_code: response.code,
+                      server_hostname: server_hostname,
+                      retry_sleep: retry_sleep})
+
+      ::Kernel.sleep(retry_sleep)
+
+      return nil
+    end
+
+    # Parse the value of a Retry-After header
+    #
+    # Parses a string containing an Integer or RFC 2822 datestamp and returns
+    # an integer number of seconds before a request can be retried.
+    #
+    # @param header_value [String] The value of the Retry-After header.
+    #
+    # @return [Integer] Number of seconds to wait before retrying the
+    #   request. Will be equal to 0 for the case of date that has already
+    #   passed.
+    # @return [nil] Returns `nil` when the `header_value` can't be
+    #   parsed as an Integer or RFC 2822 date.
+    def parse_retry_after_header(header_value)
+      retry_after = begin
+                      Integer(header_value)
+                    rescue TypeError, ArgumentError
+                      begin
+                        DateTime.rfc2822(header_value)
+                      rescue ArgumentError
+                        return nil
+                      end
+                    end
+
+      case retry_after
+      when Integer
+        retry_after
+      when DateTime
+        sleep = (retry_after.to_time - DateTime.now.to_time).to_i
+        (sleep > 0) ? sleep : 0
+      end
+    end
+
     def apply_options_to(request, options)
       request["User-Agent"] = Puppet[:http_user_agent]
 
@@ -222,15 +310,20 @@ module Puppet::Network::HTTP
       # can be nil
       peer_cert = @verify.peer_certs.last
 
-      if peer_cert && !OpenSSL::SSL.verify_certificate_identity(peer_cert.content, site.host)
-        valid_certnames = [peer_cert.name, *peer_cert.subject_alt_names].uniq
-        msg = valid_certnames.length > 1 ? _("one of %{certnames}") % { certnames: valid_certnames.join(', ') } : valid_certnames.first
-        msg += _("Server hostname '%{host}' did not match server certificate; expected %{msg}") % { host: site.host, msg: msg }
-        raise Puppet::Error, msg, error.backtrace
-      elsif error.message.include? "certificate verify failed"
+      if error.message.include? "certificate verify failed"
         msg = error.message
         msg << ": [" + @verify.verify_errors.join('; ') + "]"
         raise Puppet::Error, msg, error.backtrace
+      elsif peer_cert && !OpenSSL::SSL.verify_certificate_identity(peer_cert.content, site.host)
+        valid_certnames = [peer_cert.name, *peer_cert.subject_alt_names].uniq
+        if valid_certnames.size > 1
+          expected_certnames = _("expected one of %{certnames}") % { certnames: valid_certnames.join(', ') }
+        else
+          expected_certnames = _("expected %{certname}") % { certname: valid_certnames.first }
+        end
+
+        msg = _("Server hostname '%{host}' did not match server certificate; %{expected_certnames}") % { host: site.host, expected_certnames: expected_certnames }
+        raise Puppet::Error, msg, error.backtrace
       else
         raise
       end
