@@ -24,8 +24,8 @@ class Puppet::Parser::Compiler
     if !errors.empty?
       errors.each { |e| Puppet.err(e) } if errors.size > 1
       errmsg = [
-        "Compilation has been halted because: #{errors.first}",
-        "For more information, see https://docs.puppet.com/puppet/latest/reference/environments.html",
+        _("Compilation has been halted because: %{error}") % { error: errors.first },
+        _("For more information, see https://docs.puppet.com/puppet/latest/reference/environments.html"),
       ]
       raise(Puppet::Error, errmsg.join(' '))
     end
@@ -36,7 +36,7 @@ class Puppet::Parser::Compiler
     Puppet.log_exception(detail)
     raise
   rescue => detail
-    message = "#{detail} on node #{node.name}"
+    message = _("%{message} on node %{node}") % { message: detail, node: node.name }
     Puppet.log_exception(detail, message)
     raise Puppet::Error, message, detail.backtrace
  end
@@ -352,7 +352,7 @@ class Puppet::Parser::Compiler
   # evaluated later in the process.
   #
   def evaluate_classes(classes, scope, lazy_evaluate = true)
-    raise Puppet::DevError, "No source for scope passed to evaluate_classes" unless scope.source
+    raise Puppet::DevError, _("No source for scope passed to evaluate_classes") unless scope.source
     class_parameters = nil
     # if we are a param class, save the classes hash
     # and transform classes to be the keys
@@ -470,7 +470,8 @@ class Puppet::Parser::Compiler
         component = krt.find_hostclass(component_name)
       end
       if component.nil?
-        raise Puppet::ParseError, "Capability mapping error: #{kind} clause references nonexistent #{component_type} #{component_name}"
+        raise Puppet::ParseError, _("Capability mapping error: %{kind} clause references nonexistent %{component_type} %{component_name}") %
+            { kind: kind, component_type: component_type, component_name: component_name }
       end
 
       blueprint = args['blueprint']
