@@ -14,8 +14,7 @@ Puppet::Parser::Functions::newfunction(:inline_template, :type => :rvalue, :arit
       begin
         wrapper.result(string)
       rescue => detail
-        raise Puppet::ParseError,
-          _("Failed to parse inline template: %{detail}") % { detail: detail }, detail.backtrace
+        raise Puppet::ParseError, _("Failed to parse inline template: %{detail}") % { detail: detail }, detail.backtrace
       end
     end.join("")
 end
