@@ -134,42 +134,18 @@ class Lexer2
     'type'     => [:TYPE,     'type',     4],
     'attr'     => [:ATTR,     'attr',     4],
     'private'  => [:PRIVATE,  'private',  7],
+    'application' => [:APPLICATION, 'application',  11],
+    'consumes'    => [:CONSUMES,    'consumes',  8],
+    'produces'    => [:PRODUCES,    'produces',  8],
+    'site'        => [:SITE,        'site',  4],
   }
 
   KEYWORDS.each {|k,v| v[1].freeze; v.freeze }
   KEYWORDS.freeze
 
-  # We maintain two different tables of tokens for the constructs
-  # introduced by application management. Which ones we use is decided in
-  # +initvars+; by selecting one or the other variant, we select whether we
-  # hit the appmgmt-specific code paths
-  APP_MANAGEMENT_TOKENS = {
-    :with_appm => {
-      'application' => [:APPLICATION, 'application',  11],
-      'consumes'    => [:CONSUMES,    'consumes',  8],
-      'produces'    => [:PRODUCES,    'produces',  8],
-      'site'        => [:SITE,        'site',  4]
-    },
-    :without_appm => {
-      'application' => [:APPLICATION_R, 'application',  11],
-      'consumes'    => [:CONSUMES_R,    'consumes',  8],
-      'produces'    => [:PRODUCES_R,    'produces',  8],
-      'site'        => [:SITE_R,        'site',  4]
-    }
-  }
-
-  APP_MANAGEMENT_TOKENS.each do |_, variant|
-    variant.each { |_,v| v[1].freeze; v.freeze }
-    variant.freeze
-  end
-  APP_MANAGEMENT_TOKENS.freeze
-
   # Reverse lookup of keyword name to string
   KEYWORD_NAMES = {}
   KEYWORDS.each {|k, v| KEYWORD_NAMES[v[0]] = k }
-  APP_MANAGEMENT_TOKENS.each do |_, variant|
-    variant.each { |k,v| KEYWORD_NAMES[v[0]] = k }
-  end
   KEYWORD_NAMES.freeze
 
   PATTERN_WS        = %r{[[:blank:]\r]+}
@@ -203,7 +179,7 @@ class Lexer2
   # PERFORMANCE NOTE:
   # Comparison against a frozen string is faster (than unfrozen).
   #
-  STRING_BSLASH_BSLASH = '\\'.freeze
+  STRING_BSLASH_SLASH = '\/'.freeze
 
   attr_reader :locator
 
@@ -376,8 +352,10 @@ class Lexer2
           # regexp position is a regexp, else a div
           if regexp_acceptable? && value = scn.scan(PATTERN_REGEX)
             # Ensure an escaped / was not matched
-            while value[-2..-2] == STRING_BSLASH_BSLASH # i.e. \\
-              value += scn.scan_until(PATTERN_REGEX_END)
+            while escaped_end(value)
+              more = scn.scan_until(PATTERN_REGEX_END)
+              return emit(TOKEN_DIV, before) unless more
+              value << more
             end
             regex = value.sub(PATTERN_REGEX_A, '').sub(PATTERN_REGEX_Z, '').gsub(PATTERN_REGEX_ESC, '/')
             emit_completed([:REGEX, Regexp.new(regex), scn.pos-before], before)
@@ -550,7 +528,7 @@ class Lexer2
         before = scn.pos
         value = scn.scan(PATTERN_BARE_WORD)
         if value && value =~ PATTERN_NAME
-          emit_completed(KEYWORDS[value] || @appm_keywords[value] || [:NAME, value.freeze, scn.pos - before], before)
+          emit_completed(KEYWORDS[value] || [:NAME, value.freeze, scn.pos - before], before)
         elsif value
           emit_completed([:WORD, value.freeze, scn.pos - before], before)
         else
@@ -597,6 +575,21 @@ class Lexer2
     @selector.freeze
   end
 
+  # Determine if last char of value is escaped by a backslash
+  def escaped_end(value)
+    escaped = false
+    if value.end_with?(STRING_BSLASH_SLASH)
+      value[1...-1].each_codepoint do |cp|
+        if cp == 0x5c # backslash
+          escaped = !escaped
+        else
+          escaped = false
+        end
+      end
+    end
+    escaped
+  end
+
   # Clears the lexer state (it is not required to call this as it will be garbage collected
   # and the next lex call (lex_string, lex_file) will reset the internal state.
   #
@@ -613,10 +606,10 @@ class Lexer2
   # overloading of = does not allow passing more than one argument).
   #
   def string=(string)
-    lex_string(string, '')
+    lex_string(string, nil)
   end
 
-  def lex_string(string, path='')
+  def lex_string(string, path=nil)
     initvars
     assert_not_bom(string)
     @scanner = StringScanner.new(string)
@@ -670,8 +663,6 @@ class Lexer2
       :after => nil,
       :line_lexical_start => 0
     }
-    appm_mode = Puppet[:app_management] ? :with_appm : :without_appm
-    @appm_keywords = APP_MANAGEMENT_TOKENS[appm_mode]
   end
 
   # Scans all of the content and returns it in an array
