@@ -143,7 +143,7 @@ class Puppet::Provider
     elsif superclass.respond_to? :command and command = superclass.command(name)
       # nothing
     else
-      raise Puppet::DevError, "No command #{name} defined for provider #{self.name}"
+      raise Puppet::DevError, _("No command %{command} defined for provider %{provider}") % { command: name, provider: self.name }
     end
 
     which(command)
@@ -374,7 +374,7 @@ class Puppet::Provider
   # @raise [Puppet::DevError] Error indicating that the method should have been implemented by subclass.
   # @see prefetch
   def self.instances
-    raise Puppet::DevError, "Provider #{self.name} has not defined the 'instances' class method"
+    raise Puppet::DevError, _("Provider %{provider} has not defined the 'instances' class method") % { provider: self.name }
   end
 
   # Creates getter- and setter- methods for each property supported by the resource type.
@@ -446,7 +446,7 @@ class Puppet::Provider
       klass = param
     else
       unless klass = resource_type.attrclass(param)
-        raise Puppet::DevError, "'#{param}' is not a valid parameter for #{resource_type.name}"
+        raise Puppet::DevError, _("'%{parameter_name}' is not a valid parameter for %{resource_type}") % { parameter_name: param, resource_type: resource_type.name }
       end
     end
     return true unless features = klass.required_features
@@ -530,7 +530,7 @@ class Puppet::Provider
     elsif self.resource
       resource.name
     else
-      raise Puppet::DevError, "No resource and no name in property hash in #{self.class.name} instance"
+      raise Puppet::DevError, _("No resource and no name in property hash in %{class_name} instance") % { class_name: self.class.name }
     end
   end
 
