@@ -196,8 +196,9 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     # zeroes. If someone attempts to use a password hash that worked with
     # a previous version of OS X, we will fail early and warn them.
     if password_hash.length != 136
-      fail(_("OS X 10.7 requires a Salted SHA512 hash password of 136 characters. \
-           Please check your password and try again."))
+      #TRANSLATORS 'OS X 10.7' is an operating system and should not be translated, 'Salted SHA512' is the name of a hashing algorithm
+      fail(_("OS X 10.7 requires a Salted SHA512 hash password of 136 characters.") +
+           ' ' + _("Please check your password and try again."))
     end
 
     plist_file = "#{users_plist_dir}/#{resource_name}.plist"
@@ -372,7 +373,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
   # expects to be returned by addcmd. Thus we don't bother defining addcmd.
   def create
     if exists?
-      info "already exists"
+      info _("already exists")
       return nil
     end
 
