@@ -100,10 +100,10 @@ Puppet::Type.type(:package).provide(:appdmg, :parent => Puppet::Provider::Packag
   def install
     source = nil
     unless source = @resource[:source]
-      self.fail "Mac OS X PKG DMGs must specify a package source."
+      self.fail _("Mac OS X PKG DMGs must specify a package source.")
     end
     unless name = @resource[:name]
-      self.fail "Mac OS X PKG DMGs must specify a package name."
+      self.fail _("Mac OS X PKG DMGs must specify a package name.")
     end
     self.class.installpkgdmg(source,name)
   end
