@@ -39,7 +39,7 @@ Puppet::Type.type(:package).provide :apple, :parent => Puppet::Provider::Package
   def install
     source = nil
     unless source = @resource[:source]
-      self.fail "Mac OS X packages must specify a package source"
+      self.fail _("Mac OS X packages must specify a package source")
     end
 
     installer "-pkg", source, "-target", "/"
