@@ -171,7 +171,7 @@ Puppet::Type.type(:service).provide :init, :parent => :base do
 
   def texecute(type, command, fof = true, squelch = false, combine = true)
     if type == :start && Facter.value(:osfamily) == "Solaris"
-        command =  ["/usr/bin/ctrun -l none", command].flatten.join(" ")
+        command =  ["/usr/bin/ctrun -l child", command].flatten.join(" ")
     end
     super(type, command, fof, squelch, combine)
   end
